@@ -13,7 +13,9 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
+
+sub content_type { "text/plain" }
 
 sub format_pretty {
     my ($data, $opts) = @_;
@@ -361,7 +363,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -506,13 +508,15 @@ into:
 
 Modules used for formatting: L<Text::ASCIITable>, L<YAML>.
 
+L<Data::Format::Pretty>
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
